@@ -19,9 +19,15 @@ def minimizer_styles(context):
 
 @register.inclusion_tag('minimizer/tags/scripts.html', takes_context=True)
 def minimizer_scripts(context):
+    # FIXME: optimize it.
+    scripts = []
+    for script in get_minimizer_list(settings.SCRIPTS):
+        is_coffee = os.path.splitext(script)[-1] == '.coffee'
+        scripts.append([script, is_coffee])
+
     arguments = {
         'STATIC_URL': context['STATIC_URL'],
-        'scripts': get_minimizer_list(settings.SCRIPTS)
+        'scripts': scripts
     }
 
     return arguments
